<?php
/*
Plugin Name: WordPress FAQ Manager
Plugin URI: http://andrewnorcross.com/tools/faq-manager/
Description: Uses custom post types and taxonomies to manage an FAQ section for your site.
Author: Andrew Norcross
Version: 1.03
Requires at least: 3.0
Author URI: http://andrewnorcross.com
*/
/*  Copyright 2011 Andrew Norcross

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License (GPL v2) only.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
// flush permalinks on plugin initalization ****thanks to Austin Passay @TheFrosty for the help****

function faq_flush_rewrite_rules() {
	global $pagenow, $wp_rewrite;
	if ('plugins.php' == $pagenow && isset( $_GET['activate'] ) )
		$wp_rewrite->flush_rules();
}
add_action('load-plugins.php', 'faq_flush_rewrite_rules' );

// Shortcode to allow placement of FAQs
// Can either be a complete list or separated by slugs (single only at this time)

//include admin page
include('inc/faq-admin.php');

if(get_option('faq_widget') == 'true') {
	include('inc/faq-widget.php');
}

	function faq_shortcode($atts, $content = NULL) {
		extract(shortcode_atts(array(
			'faq_topic'	=> '',
			'faq_tag'	=> '',
			'faq_id'	=> '',
			'limit'		=> '10',
		), $atts));
		$faq_topic = preg_replace('~&#x0*([0-9a-f]+);~ei', 'chr(hexdec("\\1"))', $faq_topic);
		$faq_tag = preg_replace('~&#x0*([0-9a-f]+);~ei', 'chr(hexdec("\\1"))', $faq_tag);
			$faqs = new WP_Query(array(
				'p'					=> ''.$faq_id.'',
				'faq-topic'			=> ''.$faq_topic.'',
				'faq-tags'			=> ''.$faq_tag.'',
				'post_type'			=>	'question',
				'posts_per_page'	=>	''.$limit.'',
				'orderby'			=>	'menu_order',
				'order'				=>	'ASC'
				));
			$displayfaq= '<div class="faq_list">';
				while ($faqs->have_posts()) : $faqs->the_post();
				global $post;
				$displayfaq .= '<div class="single_faq">';
				$displayfaq .= '<h3 class="faq_question">'.get_the_title().'</h3>';
				$displayfaq .= '<p class="faq_answer">'.get_the_content().'</p>';
				$displayfaq .= '</div>';
				endwhile;
			wp_reset_query();
			$displayfaq .= '</div>';
		return $displayfaq;
		}

add_shortcode('faq','faq_shortcode');

function faqlist_shortcode($atts, $content = NULL) {
		extract(shortcode_atts(array(
			'faq_topic'	=> '',
			'faq_tag'	=> '',
			'faq_id'	=> '',
			'limit'		=> '10',
		), $atts));
		$faq_topic = preg_replace('~&#x0*([0-9a-f]+);~ei', 'chr(hexdec("\\1"))', $faq_topic);
		$faq_tag = preg_replace('~&#x0*([0-9a-f]+);~ei', 'chr(hexdec("\\1"))', $faq_tag);
			$faqs = new WP_Query(array(
				'p'					=> ''.$faq_id.'',
				'faq-topic'			=> ''.$faq_topic.'',
				'faq-tags'			=> ''.$faq_tag.'',
				'post_type'			=>	'question',
				'posts_per_page'	=>	''.$limit.'',
				'orderby'			=>	'menu_order',
				'order'				=>	'ASC'
				));
			$displayfaq= '<div class="faq_list">';
				while ($faqs->have_posts()) : $faqs->the_post();
				global $post;
				$displayfaq .= '<div class="single_faq">';
				$displayfaq .= '<h3 class="faqlist_question"><a href="'.get_permalink().'" title="Permanent link to '.get_the_title().'" >'.get_the_title().'</a></h3>';
				$displayfaq .= '</div>';
				endwhile;
			wp_reset_query();
			$displayfaq .= '</div>';
		return $displayfaq;
		}

add_shortcode('faqlist','faqlist_shortcode');

// Register Custom Taxonomy and Post Type 

add_action( 'init', '_init_faq_post_type' );

function _init_faq_post_type() {
	register_post_type( 'question',
		array(
			'labels' => array(
				'name' => __( 'FAQs' ),
				'singular_name' => __( 'FAQ' ),
				'add_new' => __( 'Add New FAQ' ),
				'add_new_item' => __( 'Add New FAQ' ),
				'edit' => __( 'Edit' ),
				'edit_item' => __( 'Edit FAQ' ),
				'new_item' => __( 'New FAQ' ),
				'view' => __( 'View FAQ' ),
				'view_item' => __( 'View FAQ' ),
				'search_items' => __( 'Search FAQ' ),
				'not_found' => __( 'No FAQs found' ),
				'not_found_in_trash' => __( 'No FAQs found in Trash' ),
			),
			'public' => true,
			'show_in_nav_menus' => false,			
			'show_ui' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'hierarchical' => false,
			'menu_position' => 20,
			'capability_type' => 'post',
			'menu_icon' => WP_PLUGIN_URL . '/' . plugin_basename(dirname(__FILE__)) .'/inc/img/faq_menu.png',
			'query_var' => true,
			'rewrite' => true,
			'supports' => array('title', 'editor', 'author'),
		)
	);
	// register topics (categories) for FAQs
	register_taxonomy(
		'faq-topic',
		array( 'question' ),
		array(
			'public' => true,
			'show_in_nav_menus' => true,
			'show_ui' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'rewrite' => array( 'slug' => 'topics', 'with_front' => true ),
			'hierarchical' => true,
			'query_var' => true,
			'labels' => array(
				'name' => __( 'FAQ Topics' ),
				'singular_name' => __( 'FAQ Topic' ),
				'search_items' => __( 'Search FAQ Topics' ),
				'popular_items' => __( 'Popular FAQ Topics' ),
				'all_items' => __( 'All FAQ Topics' ),
				'parent_item' => __( 'Parent FAQ Topic' ),
				'parent_item_colon' => __( 'Parent FAQ Topic:' ),
				'edit_item' => __( 'Edit FAQ Topics' ),
				'update_item' => __( 'Update FAQ Topics' ),
				'add_new_item' => __( 'Add New FAQ Topics' ),
				'new_item_name' => __( 'New FAQ Topics' ),
			),
		)
	);
	register_taxonomy_for_object_type('question', 'faq-topic');
	// register tags for FAQs
	register_taxonomy(
		'faq-tags',
		array( 'question' ),
		array(
			'public' => true,
			'show_in_nav_menus' => true,
			'show_ui' => true,
			'publicly_queryable' => true,
			'exclude_from_search' => false,
			'rewrite' => array( 'slug' => 'faq-tags', 'with_front' => true ),
			'hierarchical' => false,
			'query_var' => true,
			'labels' => array(
				'name' => __( 'FAQ Tags' ),
				'singular_name' => __( 'FAQ Tag' ),
				'search_items' => __( 'Search FAQ Tags' ),
				'popular_items' => __( 'Popular FAQ Tags' ),
				'all_items' => __( 'All FAQ Tags' ),
				'parent_item' => __( 'Parent FAQ Tags' ),
				'parent_item_colon' => __( 'Parent FAQ Tag:' ),
				'edit_item' => __( 'Edit FAQ Tag' ),
				'update_item' => __( 'Update FAQ Tag' ),
				'add_new_item' => __( 'Add New FAQ Tag' ),
				'new_item_name' => __( 'New FAQ Tag' ),
			),
		)
	);
	register_taxonomy_for_object_type('question', 'faq-tags');
}

// Add columns to FAQ list page

add_filter('manage_edit-question_columns', 'add_new_question_columns');

	function add_new_question_columns($question_columns) {
		$new_columns['cb'] = '<input type="checkbox" />';
		$new_columns['title'] = _x('Question', 'column name');
		$new_columns['answers'] = __('Answer');
		$new_columns['faq_cat'] = __('FAQ Topic');
		$new_columns['faq_tags'] = __('FAQ Tags');		
		$new_columns['date'] = _x('Date', 'column name');
 
		return $new_columns;
	}

add_action('manage_posts_custom_column', 'manage_question_columns', 10, 2);
 
	function manage_question_columns($column_name, $id) {
		global $post;
		switch ($column_name) {
 		case 'answers':
			echo the_excerpt();
		        break;
 		case 'faq_cat':
			echo get_the_term_list( $post->ID, 'faq-topic', '', ', ', '');
		        break;
 		case 'faq_tags':
			echo get_the_term_list( $post->ID, 'faq-tags', '', ', ', '');
		        break;
		default:
			break;
		} // end switch
	}


// add admin CSS for FAQ post table
function custom_faq_type_css() {
	// this is my half-assed attempt at internationalization
	$x = ( 'rtl' == get_bloginfo( 'text_direction' ) ) ? 'left' : 'right';

	echo "
	<style type='text/css'>
	.widefat th#id {width:35px;}
	.widefat th#questions {width:200px;}	
	.widefat th#answers {width:400px;}
	ul.faqinfo {margin-left:15px;}
	p.indent {text-indent:10px;}
	p.norcross_donate {margin-top:50px;}
	</style>
	";
}

add_action('admin_head', 'custom_faq_type_css');

// change post title box text

function change_faq_title_text( $title ){
	$screen = get_current_screen();
	if ( 'question' == $screen->post_type ) {
		$title = 'Enter Question Title Here';
	}
	return $title;
}
add_filter( 'enter_title_here', 'change_faq_title_text' );


?>